@@ -17,7 +17,7 @@
 #' @param legend logical. should a legend be added to the plot? Default: TRUE
 #' @param ci logical. Should confidence intervals be plotted. Default = NULL
 #' @param legendposition numeric. x, y position of the legend if plotted. Default: c(0.85, 0.8)
-#' @param linecols Character. Colour brewer pallettes too colour lines. Default: 'Set1', "black" for black with dashed line.
+#' @param linecols Character or Character vector. Colour brewer pallettes too colour lines. Default ="Set1", "black" for black with dashed line, character vector for the customization of line colors.
 #' @param dashed logical. Should a variety of linetypes be used to identify lines. Default: FALSE
 #' @param cumhaz Show cumulaive incidence function, Default: F
 #' @param design Data design for reactive design data , Default: NULL
@@ -253,7 +253,7 @@ svyjskm <- function(sfit,
   # specifying axis parameteres etc #
   ###################################
 
-  if (dashed == TRUE | linecols == "black") {
+  if (dashed == TRUE | all(linecols == "black")) {
     linetype <- c("solid", "dashed", "dotted", "dotdash", "longdash", "twodash", "1F", "F1", "4C88C488", "12345678")
   } else {
     linetype <- c("solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid", "solid")
@@ -269,7 +269,7 @@ svyjskm <- function(sfit,
   p <- ggplot2::ggplot(df, aes(x = time, y = surv, colour = strata, linetype = strata)) +
     ggtitle(main)
   linecols2 <- linecols
-  if (linecols == "black") {
+  if (all(linecols == "black")) {
     linecols <- "Set1"
     p <- ggplot2::ggplot(df, aes(x = time, y = surv, linetype = strata)) +
       ggtitle(main)
@@ -317,18 +317,36 @@ svyjskm <- function(sfit,
       scale_linetype_manual(name = ystrataname, values = linetype)
   }
 
+  brewer.palette <- c(
+    "BrBG", "PiYG", "PRGn", "PuOr", "RdBu", "RdGy", "RdYlBu", "RdYlGn", "Spectral", "Accent", "Dark2", "Paired", "Pastel1", "Pastel2",
+    "Set1", "Set2", "Set3", "Blues", "BuGn", "BuPu", "GnBu", "Greens", "Greys", "Oranges", "OrRd", "PuBu", "PuBuGn", "PuRd", "Purples",
+    "RdPu", "Reds", "YlGn", "YlGnBu", "YlOrBr", "YlOrRd"
+  )
+
   if (!is.null(theme) && theme == "jama") {
-    p <- p + scale_color_manual(name = ystrataname, values = c("#00AFBB", "#E7B800", "#FC4E07"))
+    col.pal <- c("#00AFBB", "#E7B800", "#FC4E07")
+    col.pal <- rep(col.pal, ceiling(length(ystratalabs) / 3))
+  } else if (all(linecols %in% brewer.palette)) {
+    col.pal <- NULL
   } else {
+    col.pal <- linecols
+    col.pal <- rep(col.pal, ceiling(length(ystratalabs) / length(linecols)))
+  }
+
+  if (is.null(col.pal)) {
     p <- p + scale_colour_brewer(name = ystrataname, palette = linecols)
+  } else {
+    p <- p + scale_color_manual(name = ystrataname, values = col.pal)
   }
 
   # Add 95% CI to plot
-  if (ci) {
-    if (linecols2 == "black") {
+  if (ci == TRUE) {
+    if (all(linecols2 == "black")) {
       p <- p + geom_ribbon(data = df, aes(ymin = lower, ymax = upper), alpha = 0.25, colour = NA)
-    } else {
+    } else if (is.null(col.pal)) {
       p <- p + geom_ribbon(data = df, aes(ymin = lower, ymax = upper, fill = strata), alpha = 0.25, colour = NA) + scale_fill_brewer(name = ystrataname, palette = linecols)
+    } else {
+      p <- p + geom_ribbon(data = df, aes(ymin = lower, ymax = upper, fill = strata), alpha = 0.25, colour = NA) + scale_fill_manual(name = ystrataname, values = col.pal)
     }
   }
 
